condQpc: Calculate conditional Qpc

condQpcR Documentation

Calculate conditional Qpc

Description

This function calculates Qpc given data about the relatedness matrix, and a set of trait values

Usage

condQpc(myZ, myU, myLambdas, myM, myL)

Arguments

myZ

two columned data frame containing vectors of two traits. Not normalized yet. The first trait is the one we're testing for selection on conditional on the second trait.

myU

matrix of eigenvectors of the kinship matrix (each column is an eigenvector)

myLambdas

vector of eigenvalues of the kinship matrix

myM

the range of PCs you want to test for selection

myL

the range of PCs used to estimate Va

Examples

calcQpc()

emjosephs/quaint documentation built on June 10, 2025, 2:03 a.m.