make_k: Kinship matrix function for complete data using the estimated...

make_kR Documentation

Kinship matrix function for complete data using the estimated variance across all loci

Description

This function makes a kinship matrix using the cov function. It standardizes by the estimated genic variance across all loci, not each locus individually

Usage

make_k(myG)

Arguments

myG

matrix where the rows are individuals/populations and the columns are loci and the values are the allele frequency (not the # of copies present in an individual!!!).


emjosephs/quaint documentation built on June 10, 2025, 2:03 a.m.