var0: Calculate variance where the mean is set to zero

View source: R/var0.R

var0R Documentation

Calculate variance where the mean is set to zero

Description

This function takes a string of numbers and calculates the variance of these numbers, assuming that the mean is 0.

Usage

var0(x)

Arguments

x

a string of vectors


emjosephs/quaint documentation built on June 10, 2025, 2:03 a.m.