| condQpc | R Documentation |
This function calculates Qpc given data about the relatedness matrix, and a set of trait values
condQpc(myZ, myU, myLambdas, myM, myL)
myZ |
two columned data frame containing vectors of two traits. Not normalized yet. The first trait is the one we're testing for selection on conditional on the second trait. |
myU |
matrix of eigenvectors of the kinship matrix (each column is an eigenvector) |
myLambdas |
vector of eigenvalues of the kinship matrix |
myM |
the range of PCs you want to test for selection |
myL |
the range of PCs used to estimate Va |
calcQpc()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.