| make_k | R Documentation |
This function makes a kinship matrix using the cov function. It standardizes by the estimated genic variance across all loci, not each locus individually
make_k(myG)
myG |
matrix where the rows are individuals/populations and the columns are loci and the values are the allele frequency (not the # of copies present in an individual!!!). |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.