| var0 | R Documentation |
This function takes a string of numbers and calculates the variance of these numbers, assuming that the mean is 0.
var0(x)
x |
a string of vectors |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.